*****************************************

                *analysis.do*
				
*****************************************

/*       
This Stata do-file 

2. creates summary statistic table. (Table 2 in the paper)
3. runs first stage probits (Table 3 in the paper)
4. conducts tests for weak iv in the first stage probits
5. writes program for homoskedastic ESM estimation
6. writes program for Procedure 3.1 
7. writes program for Procedure 3.2 with polynomial sieves
8. writes program for Procedure 3.2 with spline sieves
9. runs the procedures (Table 4 in the paper)
*/


clear all
capture log close
cd "FILEPATH_DATA" // change folder location to where you have saved the data_2007_2016.dta and analysis.do



use data_2007_2016.dta, clear

// survey weights
gen mec10yr = 1/5*wtdrd1 if sddsrvyr==5|sddsrvyr==6|sddsrvyr==7|sddsrvyr==8 | sddsrvyr==9
svyset sdmvpsu [pw = mec10yr], strata(sdmvstra) singleunit(centered)
svydescribe
gen ID = _n
*tab sddsrvyr, gen(year)

#delimit ;
global covariatesfordm
year2 year3 year4 year5 age female hisp white black other educ1 educ2 educ3 educ4 educ5 married bp cholestrol hi rc arthritis heart diabetic bmi income2100 income5400 income8400 income8400more employed kcal logkcal;
#delimit cr
foreach var in $covariatesfordm{
drop if `var'==.
sum `var'
gen dm`var'=`var'-r(mean)
gen `var'Xadvice = `var'*advice
gen `var'Xhi = `var'*hi
gen `var'Xrc = `var'*rc
}


drop if kcal<=1800
drop if female==1&ridexprg==1
drop if advice == .
drop if bmi < 25
gen bmi2 = bmi*bmi

*GLOBAL: pchirc probit covariates hi rc
#delimit ;
global pchirc year2 year3 year4 year5 female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol hi rc arthritis heart diabetic  bmi income2100 income5400 income8400  employed;
#delimit cr

*GLOBAL: pchi probit covariates hi
#delimit ;
global pchi year2 year3 year4 year5 female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol hi  arthritis heart diabetic  bmi income2100 income5400 income8400  employed;
#delimit cr

*GLOBAL: pchi probit covariates rc
#delimit ;
global pcrc year2 year3 year4 year5 female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol rc arthritis heart diabetic  bmi income2100 income5400 income8400  employed;
#delimit cr

*GLOBAL: INTERACTIONCOVARIATESFOROLS instruments for interaction variables
#delimit ;
global interactioncovariatesforols dmyear2 dmyear3 dmyear4 dmyear5 dmage dmfemale dmhisp  dmblack dmother  dmeduc2 dmeduc3 dmeduc4 dmeduc5 dmmarried dmbp dmcholestrol  dmarthritis dmheart dmdiabetic  dmbmi dmincome2100 dmincome5400 dmincome8400  dmemployed;

#delimit cr

foreach var in $interactioncovariatesforols{
gen `var'Xadvice = `var'*advice
gen `var'Xhi = `var'*hi
gen `var'Xrc = `var'*rc
}

#delimit cr
label variable female "Female"
label variable advice "Advice"
label variable bp "High BP"
label variable cholestrol "Cholestrol"
label variable heart "Heart Condition"
label variable diabetic "Diabetes"
label variable arthritis "Arthiritis"
label variable hisp "Hispanic"
label variable black "Black"
label variable other "Other"
label variable educ2 "9th grade"
label variable educ3 "High School / GED"
label variable educ4 "Some College / AA"
label variable educ5 "College and above"
label variable married "Married"
label variable income2100 "Income $<$ \$2100"
label variable income5400 "\$2100$<$Income$<$\$5400"
label variable income8400 "\$5400$<$Income$<$\$8400"
label variable employed "Employed"

*---------------------------------------
**# SUMMARY STATISTICS
*---------------------------------------
#delimit ;

svy: mean kcal advice age female hisp white  black other educ1 educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400 income8400more bp cholestrol heart diabetic arthritis hi rc;
svy: mean kcal  age female hisp white  black other educ1 educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400 income8400more bp cholestrol heart diabetic arthritis hi rc if advice == 1;
svy: mean kcal age female hisp white  black other educ1 educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400 income8400more bp cholestrol heart diabetic arthritis hi rc if advice == 0;
#delimit cr

*---------------------------------------
**# PROBITS
*---------------------------------------

* PROBIT
svy: probit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc

test hi rc

* PROBIT MARGINS
margins, dydx(age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc) atmeans post
test hi rc

* STORE
estimates store marginsprobit
outreg2 using "probits.tex",  keep(age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc) nocons label dec(3)replace

* PROBIT FOR INITIALS
svy: probit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc
matrix define initialhet = (e(b)) 
* HETPROBIT PARAMETRIC
svy:hetprobit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc, het(bmi ) from(initialhet)
test hi rc


margins, dydx(age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc) atmeans post
test hi rc 

estimates store marginshetprobit
outreg2 using "probits.tex",  keep(age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc) nocons label dec(3) append 

*HETPROBIT SIEVE 1
svy:hetprobit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc, het(bmi bmi2) from(initialhet)

margins, dydx(age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc) atmeans post
test hi rc

estimates store marginshetprobitsieve
outreg2 using "probits.tex",  keep(age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc) nocons label dec(3) append

**********************************************************************
**********************************************************************
*WEAK IV TEST*
**********************************************************************
**********************************************************************
ivregress 2sls logkcal year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis (advice = hi rc),  robust
weakivtest

**********************************************************************
**********************************************************************
*HET PROBIT STAT FOR HETEROSKEDASTICITY*
**********************************************************************
**********************************************************************
hetprobit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc, het(bmi bmi2 ) waldhet


*---------------------------------------
**# PROGRAM FOR CC HOM 
*---------------------------------------

capture program drop proc_cchom
program proc_cchom, rclass
tempvar touse
gen byte `touse' = 1
#delimit ;
svy: probit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc;

predict zgamma, xb;
gen sigma_hat = 1;
gen index = zgamma/sigma_hat;
gen lambda_mz = normalden(-index)/(normal(-index));
gen lambda_z = normalden(index)/normal(index);
gen gr = advice*lambda_z-(1-advice)*lambda_mz;

svy: reg logkcal advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis
dmyear2Xadvice dmyear3Xadvice dmyear4Xadvice dmyear5Xadvice dmageXadvice dmfemaleXadvice dmhispXadvice dmblackXadvice dmotherXadvice dmeduc2Xadvice dmeduc3Xadvice dmeduc4Xadvice dmeduc5Xadvice dmmarriedXadvice dmbpXadvice dmcholestrolXadvice dmarthritisXadvice dmheartXadvice dmdiabeticXadvice  dmbmiXadvice dmincome2100Xadvice dmincome5400Xadvice dmincome8400Xadvice dmemployedXadvice gr;
drop zgamma sigma_hat index lambda_mz lambda_z gr  ;
#delimit cr
end

*---------------------------------------
**# PROGRAM FOR CC HET PARA 
*---------------------------------------

capture program drop proc_cchetparahirc
program proc_cchetparahirc, rclass
tempvar touse
gen byte `touse' = 1
#delimit ;
svy: probit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc;
matrix define initialhet = (e(b));
svy: hetprobit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc, het(bmi);

predict zgamma, xb;
predict sigma_hat, sigma;
gen index = zgamma/sigma_hat;
gen lambda_mz = normalden(-index)/(normal(-index));
gen lambda_z = normalden(index)/normal(index);
gen gr = advice*lambda_z-(1-advice)*lambda_mz;
gen bmiXgr = bmi*gr;
gen adviceXgr = advice*gr;
gen bmiXadviceXgr = bmi*advice*gr;
svy: reg logkcal advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis
dmyear2Xadvice dmyear3Xadvice dmyear4Xadvice dmyear5Xadvice dmageXadvice dmfemaleXadvice dmhispXadvice dmblackXadvice dmotherXadvice dmeduc2Xadvice dmeduc3Xadvice dmeduc4Xadvice dmeduc5Xadvice dmmarriedXadvice dmbpXadvice dmcholestrolXadvice dmarthritisXadvice dmheartXadvice dmdiabeticXadvice  dmbmiXadvice dmincome2100Xadvice dmincome5400Xadvice dmincome8400Xadvice dmemployedXadvice 
gr bmiXgr adviceXgr bmiXadviceXgr;

matrix drop initialhet;
drop zgamma sigma_hat index lambda_mz
lambda_z gr adviceXgr bmiXgr bmiXadviceXgr;
#delimit cr
end


*---------------------------------------
* PROGRAM FOR CC HET SIEVE 1: BMI BMI2
*---------------------------------------

capture program drop proc_cchets1
program proc_cchets1, rclass
tempvar touse
gen byte `touse' = 1
#delimit ;
svy: probit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc;
matrix define initialhet = (e(b));
svy: hetprobit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc, het(bmi bmi2);

predict zgamma, xb;
predict sigma_hat, sigma;
gen index = zgamma/sigma_hat;
gen lambda_mz = normalden(-index)/(normal(-index));
gen lambda_z = normalden(index)/normal(index);
gen gr = advice*lambda_z-(1-advice)*lambda_mz;
gen bmiXgr = bmi*gr;
gen bmi2Xgr = bmi*bmi*gr;
gen adviceXgr = advice*gr;
gen bmiXadviceXgr = bmi*advice*gr;
gen bmi2XadviceXgr = bmi*bmi*advice*gr;

svy: reg logkcal advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis 
 year2Xadvice year3Xadvice year4Xadvice year5Xadvice dmageXadvice dmfemaleXadvice dmhispXadvice dmblackXadvice dmotherXadvice dmeduc2Xadvice dmeduc3Xadvice dmeduc4Xadvice dmeduc5Xadvice dmmarriedXadvice dmbpXadvice dmcholestrolXadvice dmarthritisXadvice dmheartXadvice dmdiabeticXadvice  dmbmiXadvice dmincome2100Xadvice dmincome5400Xadvice dmincome8400Xadvice dmemployedXadvice 
gr bmiXgr bmi2Xgr adviceXgr bmiXadviceXgr bmi2XadviceXgr;

matrix drop initialhet;
drop zgamma sigma_hat index lambda_mz
lambda_z gr bmiXgr bmi2Xgr adviceXgr bmiXadviceXgr
bmi2XadviceXgr;
#delimit cr
end

*---------------------------------------
* PROGRAM FOR CC HET SIEVE 2: SPLINES
*---------------------------------------

capture program drop proc_cchets2
program proc_cchets2, rclass
tempvar touse
gen byte `touse' = 1
#delimit ;
svy: probit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc;
matrix define initialhet = (e(b));
mkspline pctbmi 5 = bmi, pctile displayknots;
svy: hetprobit advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis hi rc, het(pctbmi1 pctbmi2 pctbmi3 pctbmi4 pctbmi5);
predict zgamma, xb;
predict sigma_hat, sigma;
gen index = zgamma/sigma_hat;
gen lambda_mz = normalden(-index)/(normal(-index));
gen lambda_z = normalden(index)/normal(index);
gen gr = advice*lambda_z-(1-advice)*lambda_mz;
gen pctbmi1Xgr = pctbmi1*gr;
gen pctbmi2Xgr = pctbmi2*gr; 
gen pctbmi3Xgr = pctbmi3*gr; 
gen pctbmi4Xgr = pctbmi4*gr; 
gen pctbmi5Xgr = pctbmi5*gr;
gen adviceXgr = advice*gr;
gen pctbmi1XadviceXgr = pctbmi1*advice*gr;
gen pctbmi2XadviceXgr = pctbmi2*advice*gr; 
gen pctbmi3XadviceXgr = pctbmi3*advice*gr; 
gen pctbmi4XadviceXgr = pctbmi4*advice*gr; 
gen pctbmi5XadviceXgr = pctbmi5*advice*gr;

svy: reg logkcal advice year2 year3 year4 year5 age female hisp  black other  educ2 educ3 educ4 educ5 married bmi employed income2100 income5400 income8400  bp cholestrol heart diabetic arthritis 
 year2Xadvice year3Xadvice year4Xadvice year5Xadvice dmageXadvice dmfemaleXadvice dmhispXadvice dmblackXadvice dmotherXadvice dmeduc2Xadvice dmeduc3Xadvice dmeduc4Xadvice dmeduc5Xadvice dmmarriedXadvice dmbpXadvice dmcholestrolXadvice dmarthritisXadvice dmheartXadvice dmdiabeticXadvice  dmbmiXadvice dmincome2100Xadvice dmincome5400Xadvice dmincome8400Xadvice dmemployedXadvice 
gr pctbmi1Xgr pctbmi2Xgr pctbmi3Xgr pctbmi4Xgr pctbmi5Xgr 
adviceXgr pctbmi1XadviceXgr pctbmi2XadviceXgr pctbmi3XadviceXgr pctbmi4XadviceXgr pctbmi5XadviceXgr;

matrix drop initialhet;
drop zgamma sigma_hat index lambda_mz
lambda_z 
pctbmi1 pctbmi2 pctbmi3 pctbmi4 pctbmi5
gr pctbmi1Xgr pctbmi2Xgr pctbmi3Xgr pctbmi4Xgr pctbmi5Xgr 
adviceXgr pctbmi1XadviceXgr pctbmi2XadviceXgr pctbmi3XadviceXgr pctbmi4XadviceXgr pctbmi5XadviceXgr;
#delimit cr
end

**# REGRESSIONS
global bootreps 1000

#delimit ;

*_______________________________________________________________________________

* OLS

display "OLS" ;

svy: reg logkcal advice year2 year3 year4 year5 female hisp  black other educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed
dmyear2Xadvice dmyear3Xadvice dmyear4Xadvice dmyear5Xadvice dmageXadvice dmfemaleXadvice dmhispXadvice dmblackXadvice dmotherXadvice dmeduc2Xadvice dmeduc3Xadvice dmeduc4Xadvice dmeduc5Xadvice dmmarriedXadvice dmbpXadvice dmcholestrolXadvice dmarthritisXadvice dmheartXadvice dmdiabeticXadvice  dmbmiXadvice dmincome2100Xadvice dmincome5400Xadvice dmincome8400Xadvice dmemployedXadvice ;

outreg2 using "results.tex", keep(advice female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed) nocons label dec(3) replace  ctitle("OLS");

*_______________________________________________________________________________

* 2SLS

display "2SLS" ;

#delimit;

svy: ivregress 2sls logkcal year2 year3 year4 year5 female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed 
(advice year2Xadvice year3Xadvice year4Xadvice year5Xadvice ageXadvice femaleXadvice hispXadvice blackXadvice otherXadvice educ2Xadvice educ3Xadvice educ4Xadvice educ5Xadvice marriedXadvice bpXadvice cholestrolXadvice arthritisXadvice heartXadvice diabeticXadvice  bmiXadvice income2100Xadvice income5400Xadvice income8400Xadvice employedXadvice = hi rc
year2Xhi year3Xhi year4Xhi year5Xhi year2Xrc year3Xrc year4Xrc year5Xrc 
ageXhi femaleXhi hispXhi blackXhi otherXhi educ2Xhi educ3Xhi educ4Xhi educ5Xhi marriedXhi bpXhi cholestrolXhi arthritisXhi heartXhi diabeticXhi bmiXhi income2100Xhi income5400Xhi income8400Xhi employedXhi ageXrc femaleXrc hispXrc blackXrc otherXrc educ2Xrc educ3Xrc educ4Xrc educ5Xrc marriedXrc bpXrc cholestrolXrc arthritisXrc heartXrc diabeticXrc bmiXrc income2100Xrc income5400Xrc income8400Xrc employedXrc) ;

outreg2 using "results.tex", keep(advice female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed) nocons label dec(3) append ctitle("2SLS");

*_______________________________________________________________________________

* ESM 

display "ESM" ;

bootstrap _b,  reps($bootreps) seed(090920): proc_cchom;

outreg2 using "results.tex", keep(advice female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed) nocons label dec(3) append ctitle("ESM");

*_______________________________________________________________________________

* PROCEDURE 3.1

display "ESM HET PARA" ;

bootstrap _b,  reps($bootreps) seed(090920): proc_cchetparahirc;

outreg2 using "results.tex", keep(advice female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed) nocons label dec(3) append ctitle("Proc 3.1" );

*_______________________________________________________________________________

* PROCEDURE 3.2 WITH POLYNOMIAL SIEVES

display "ESM HET SIEVE 1";

bootstrap _b, reps($bootreps) seed(090920): proc_cchets1;

outreg2 using "results.tex", keep(advice female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed) nocons label dec(3) append ctitle("Proc 3.2 (1)");

*_______________________________________________________________________________

* PROCEDURE 3.2 WITH SPLINE SIEVES

display "ESM HET SIEVE 2" ;

bootstrap _b,  reps($bootreps) seed(090920): proc_cchets2;

outreg2 using "results.tex", keep(advice female hisp  black other  educ2 educ3 educ4 educ5 married bp cholestrol arthritis heart diabetic  bmi income2100 income5400 income8400 employed) nocons label dec(3) append ctitle("Proc 3.2 (2)");

*_______________________________________________________________________________

#delimit cr



