*****************************************

                *compiling.do*
				
*****************************************

/*       
This Stata do-file compiles NHANES datasets directly from the website. 
We compile data on several characteristics for each year.
*/

/*
NHANES FILES for years 2007-2008, 2009-2010, 2011-2012, 2013-2014, 2015-2016
1. demographics data
2. dietary data day 1
3. blood pressure and cholestrol
4. health insurance 
5. hospital utilization and access to care
6. medical conditional 
7. diabetes 
8. weight 
9. employment 
10. income 
*/

clear all
capture log close
cd "FILEPATH_RAWDATA" // change folder location to where you would like to save the raw datafiles
global folder nhanes_data "FILEPATH_RAWDATA"

**********************************************************************
**# NHANES 2007-2008*
**********************************************************************
{
clear all

***** DEMOGRAPHICS

// 1. demographics 2007-2008

import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/DEMO_E.XPT", clear
sort seqn 
save "$nhanes_data\demographics_20072008.dta", replace

// 2. dietary data day 1 total nutrients 2007-2008
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/DR1TOT_E.XPT", clear
sort seqn
save "$nhanes_data\dietaryday1_20072008.dta",replace

// 3. blood pressure and cholestrol
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/BPQ_E.XPT", clear
sort seqn
save "$nhanes_data\bpcholestrol_20072008.dta", replace

// 4. diabetes 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/DIQ_E.XPT", clear
sort seqn 
save "$nhanes_data\diabetes_20072008.dta", replace

// 5. health insurance data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/HIQ_E.XPT", clear
sort seqn
save "$nhanes_data/healthinsurance_20072008.dta", replace

// 6. hospital utilization and access to care
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/HUQ_E.XPT", clear
sort seqn
save "$nhanes_data\accesstocare_20072008.dta", replace

// 7. medical condition data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/MCQ_E.XPT", clear
sort seqn
save "$nhanes_data\medicalcondition_20072008.dta", replace

// 8. income
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/INQ_E.XPT", clear
sort seqn
save "$nhanes_data\income_20072008.dta", replace

// 9. employment
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/OCQ_E.XPT", clear
sort seqn
save "$nhanes_data\employment_20072008.dta", replace

// 10. BMI 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2007-2008/BMX_E.XPT", clear
sort seqn
save "$nhanes_data\bmi_20072008.dta", replace
}
********************************************************************************

**********************************************************************
**# NHANES 2009-2010*
**********************************************************************
{
clear all

***** DEMOGRAPHICS

// 1. demographics 2009-2010

import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/DEMO_F.XPT", clear
sort seqn 
save "$nhanes_data\demographics_20092010.dta", replace

// 2. dietary data day 2 total nutrients 2009-2010
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/DR2TOT_F.XPT", clear
sort seqn
save "$nhanes_data\dietaryday2_20092010.dta",replace

// 3. blood pressure and cholestrol
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/BPQ_F.XPT", clear
sort seqn
save "$nhanes_data\bpcholestrol_20092010.dta", replace

// 4. diabetes 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/DIQ_F.XPT", clear
sort seqn 
save "$nhanes_data\diabetes_20092010.dta", replace

// 5. health insurance data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/HIQ_F.XPT", clear
sort seqn
save "$nhanes_data/healthinsurance_20092010.dta", replace

// 6. hospital utilization and access to care
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/HUQ_F.XPT", clear
sort seqn
save "$nhanes_data\accesstocare_20092010.dta", replace

// 7. medical condition data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/MCQ_F.XPT", clear
sort seqn
save "$nhanes_data\medicalcondition_20092010.dta", replace

// 8. income
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/INQ_F.XPT", clear
sort seqn
save "$nhanes_data\income_20092010.dta", replace

// 9. employment
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/OCQ_F.XPT", clear
sort seqn
save "$nhanes_data\employment_20092010.dta", replace

// 10. BMI 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2009-2010/BMX_F.XPT", clear
sort seqn
save "$nhanes_data\bmi_20092010.dta", replace
}
********************************************************************************

**********************************************************************
**# NHANES 2011-2012*
**********************************************************************
{
clear all

***** DEMOGRAPHICS

// 1. demographics 2011-2012

import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/DEMO_G.XPT", clear
sort seqn 
save "$nhanes_data\demographics_20112012.dta", replace

// 2. dietary data day 1 total nutrients 2011-2012
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/DR1TOT_G.XPT", clear
sort seqn
save "$nhanes_data\dietaryday1_20112012.dta",replace


// 3. blood pressure and cholestrol
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/BPQ_G.XPT", clear
sort seqn
save "$nhanes_data\bpcholestrol_20112012.dta", replace

// 4. diabetes 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/DIQ_G.XPT", clear
sort seqn 
save "$nhanes_data\diabetes_20112012.dta", replace

// 5. health insurance data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/HIQ_G.XPT", clear
sort seqn
save "$nhanes_data/healthinsurance_20112012.dta", replace

// 6. hospital utilization and access to care
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/HUQ_G.XPT", clear
sort seqn
save "$nhanes_data\accesstocare_20112012.dta", replace

// 7. medical condition data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/MCQ_G.XPT", clear
sort seqn
save "$nhanes_data\medicalcondition_20112012.dta", replace

// 8. income
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/INQ_G.XPT", clear
sort seqn
save "$nhanes_data\income_20112012.dta", replace

// 9. employment
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/OCQ_G.XPT", clear
sort seqn
save "$nhanes_data\employment_20112012.dta", replace

// 10. BMI 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2011-2012/BMX_G.XPT", clear
sort seqn
save "$nhanes_data\bmi_20112012.dta", replace
}
********************************************************************************

**********************************************************************
**# NHANES 2013-2014*
**********************************************************************
{
clear all

***** DEMOGRAPHICS

// 1. demographics 2013-2014

import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/DEMO_H.XPT", clear
sort seqn 
save "$nhanes_data\demographics_20132014.dta", replace

// 2. dietary data day 1 total nutrients 2013-2014
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/DR1TOT_H.XPT", clear
sort seqn
save "$nhanes_data\dietaryday1_20132014.dta",replace


// 3. blood pressure and cholestrol
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/BPQ_H.XPT", clear
sort seqn
save "$nhanes_data\bpcholestrol_20132014.dta", replace

// 4. diabetes 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/DIQ_H.XPT", clear
sort seqn 
save "$nhanes_data\diabetes_20132014.dta", replace

// 5. health insurance data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/HIQ_H.XPT", clear
sort seqn
save "$nhanes_data/healthinsurance_20132014.dta", replace

// 6. hospital utilization and access to care
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/HUQ_H.XPT", clear
sort seqn
save "$nhanes_data\accesstocare_20132014.dta", replace

// 7. medical condition data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/MCQ_H.XPT", clear
sort seqn
save "$nhanes_data\medicalcondition_20132014.dta", replace

// 8. income
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/INQ_H.XPT", clear
sort seqn
save "$nhanes_data\income_20132014.dta", replace

// 9. employment
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/OCQ_H.XPT", clear
sort seqn
save "$nhanes_data\employment_20132014.dta", replace

// 10. BMI 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/BMX_H.XPT", clear
sort seqn
save "$nhanes_data\bmi_20132014.dta", replace
}
********************************************************************************

**********************************************************************
**# NHANES 2015-2016*
**********************************************************************
{
clear all

***** DEMOGRAPHICS

// 1. demographics 2015-2016

import sasxport5 "https://wwwn.cdc.gov/Nchs/Data/Nhanes/Public/2015/DataFiles/DEMO_I.xpt", clear
sort seqn 
save "$nhanes_data\demographics_20152016.dta", replace

// 2. dietary data day 1 total nutrients 2015-2016
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DR1TOT_I.XPT", clear
sort seqn
save "$nhanes_data\dietaryday1_20152016.dta",replace

// 3. blood pressure and cholestrol
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/BPQ_I.XPT", clear
sort seqn
save "$nhanes_data\bpcholestrol_20152016.dta", replace

// 4. diabetes 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DIQ_I.XPT", clear
sort seqn 
save "$nhanes_data\diabetes_20152016.dta", replace

// 5. health insurance data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/HIQ_I.XPT", clear
sort seqn
save "$nhanes_data/healthinsurance_20152016.dta", replace

// 6. hospital utilization and access to care
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/HUQ_I.XPT", clear
sort seqn
save "$nhanes_data\accesstocare_20152016.dta", replace

// 7. medical condition data
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/MCQ_I.XPT", clear
sort seqn
save "$nhanes_data\medicalcondition_20152016.dta", replace

// 8. income
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/INQ_I.XPT", clear
sort seqn
save "$nhanes_data\income_20152016.dta", replace

// 9. employment
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/OCQ_I.XPT", clear
sort seqn
save "$nhanes_data\employment_20152016.dta", replace

// 10. BMI 
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/BMX_I.XPT", clear
sort seqn
save "$nhanes_data\bmi_20152016.dta", replace
}
********************************************************************************
done!

/*
NEXT STEP: MERGE AND APPEND THESE DATASETS. 
PLEASE SEE THE STATA DO-FILE "merging.do"
*/