*****************************************

                *prepping.do*
				
*****************************************

/*
This Stata do-file 
1. opens the full compiled and merged raw NHANES dataset named rawdata_2007_2016.dta 
2. prepares the data for analysis
3. saves the prepped data as data_2007_2016.dta

*/


clear all
capture log close
cd "FILEPATH_RAWDATA" // change folder location to where you have saved the rawdata_2007_2016.dta
// survey years

use rawdata_2006_2016.dta, clear
tab sddsrvyr, gen(year)
gen survey_year = . 
*replace survey_year = 2017 if sddsrvyr == 10
replace survey_year = 2015 if sddsrvyr == 9
replace survey_year = 2013 if sddsrvyr == 8
replace survey_year = 2011 if sddsrvyr == 7
replace survey_year = 2009 if sddsrvyr == 6
replace survey_year = 2007 if sddsrvyr == 5

label define suryr 2007 "2007-08" 2009 "2009-10" 2011 "2011-12" 2013 "2013-14" ///
2015 "2015-16" 
label values survey_year suryr
**********************************************************************

**# TOTAL CALORIE VARIABLES

// keep observations who have reliable dietary recall status
keep if dr1drstz == 1 

// calories
gen kcal = .
replace kcal= dr1tkcal if dr1tkcal!=.
label variable kcal "energy intake"
gen logkcal = log(kcal)
label variable logkcal "log(kcal)"

**********************************************************************
**# DEMOGRAPHIC VARIABLES

// age
gen age=.
replace age = ridageyr if ridageyr!=.
label variable age "Age"
// age squared
gen age2 = age^2
label variable age2 "Age Squared"
//female
gen female=.
replace female=1 if riagendr==2&riagendr!=.
replace female =0 if riagendr==1&riagendr!=.
label variable female "Female"
label define sex 1 "Female" 0 "Male"
label value female sex
// race: dummy
gen hisp=0
replace hisp=1 if ridreth1==1| ridreth1==2
gen white=0
replace white=1 if ridreth1==3
gen black=0
replace black=1 if ridreth1==4
gen other=0
replace other=1 if ridreth1!=1&ridreth1!=2&ridreth1!=3&ridreth1!=4&ridreth1!=.
label variable white "1 if white"
label variable hisp "1 if hisp"
label variable black "1 if black"
label variable other "1 if other race"
//race: multiple
gen race = .
replace race = 1 if white == 1
replace race = 2 if black == 1
replace race = 3 if hisp == 1
replace race = 4 if other ==1
label define racev 1 "White" 2 "Black" 3 "Hispanic" 4 "Other"
label value race racev
label variable race "Race"
//education level
label define educlevel 1 "<=9thgrade" 2 "9-th grade" 3 "HS grad/GED." 4 "college/AA" 5 ">college graduate"
gen educlevel=.
replace educlevel = 1 if (dmdeduc2==1 & dmdeduc2!=7 & dmdeduc2!=9 & dmdeduc2!=.)
replace educlevel = 2 if (dmdeduc2==2 & dmdeduc2!=7 & dmdeduc2!=9 & dmdeduc2!=.)
replace educlevel = 3 if (dmdeduc2==3 & dmdeduc2!=7 & dmdeduc2!=9 & dmdeduc2!=.)
replace educlevel = 4 if (dmdeduc2==4 & dmdeduc2!=7 & dmdeduc2!=9 & dmdeduc2!=.)
replace educlevel = 5 if (dmdeduc2==5 & dmdeduc2!=7 & dmdeduc2!=9 & dmdeduc2!=.)
label value educlevel educlevel
tab educlevel
tabulate educlevel, generate(educ)
label variable educ1 "< 9th grade"
label variable educ2 "9-th grade" 
label variable educ3 "HS grad/GED" 
label variable educ4 "College/AA" 
label variable educ5 "College"
// pregnancy status
gen preg=.
replace preg=1 if ridexprg ==1 &ridexprg!=.
replace preg=0 if ridexprg==2&ridexprg!=.
label var preg "=1 if pregnant"
// bmi 
gen bmi=bmxbmi
label variable bmi "BMI"
// family income to poverty ratio
gen fpr = .
replace fpr = indfmpir if indfmpir!=.
label variable fpr "Family Income to Poverty Ratio"
// married 
gen married = .
replace married = 1 if dmdmartl == 1 & dmdmartl != .
replace married = 0 if dmdmartl != 1 
// income
gen income2100 = 0 
replace income2100 = 1 if ind235 < 6 
replace income2100 = . if ind235==77 | ind235==99 | ind235==.
label variable income2100 "<2100"

gen income5400 = 0 
replace income5400 = 1 if (ind235 >= 6 & ind235 <10)
replace income2100 = . if ind235==77 | ind235==99 | ind235==.
label variable income5400 "Above 2100 and less than 5400"

gen income8400 = 0
replace income8400 = 1 if (ind235 >= 10 & ind235 < 12)
replace income8400 = . if ind235==77 | ind235==99 | ind235==.
label variable income8400 "Above 5400 and less than 8400"

gen income8400more = 0
replace income8400more = 1 if ind235 == 12 
replace income8400more = . if ind235==77 | ind235==99 | ind235==.
label variable income8400more "Above 8400"

* employment
gen employed=0
replace employed =1 if (ocd150==1|ocd150==2)&ocd150!=7&ocd150!=9&ocd150!=.

label var employed "1 if working"


**********************************************************************
**# MEDICAL CONDITIONS

// has arthritis
gen arthritis = . 
replace arthritis = 1 if (mcq160a==1& mcq160a!=7& mcq160a!=9& mcq160a!=.)
replace arthritis = 0 if (mcq160a==2& mcq160a!=7& mcq160a!=9& mcq160a!=.)
label variable arthritis "Arthritis"
// has bp
gen bp = .
replace bp = 1 if (bpq020==1& bpq020!=7& bpq020!=9& bpq020!=.)
replace  bp = 0 if (bpq020==2& bpq020!=7& bpq020!=9& bpq020!=.)
label variable bp  "BP"
//high cholestrol
gen cholestrol = . 
replace cholestrol = 1 if (bpq080==1 & bpq080!=7& bpq080!=9& bpq080!=.)
replace cholestrol=0 if (bpq080==2 & bpq080!=7& bpq080!=9& bpq080!=.)
label variable cholestrol "Cholestrol"
// has diabetes
gen diabetic = . 
replace diabetic = 1 if (diq010==1|diq010==3)& (diq010!=7&diq010!=9&diq010!=.)
replace diabetic = 0 if (diq010==2 & diq010!=7&diq010!=9&diq010!=.)
label variable diabetic "Diabetes"
// has heart
gen heart = . 
replace heart = 1 if (mcq160c==1)& (mcq160c!=7&mcq160c!=9&mcq160c!=.)
replace heart = 0 if (mcq160c==2 & mcq160c!=7&mcq160c!=9&mcq160c!=.)
label variable heart "Heart"
**********************************************************************
**# PHYSICIANS ADVICE
gen advice = . 
*2007 and 2009
replace advice = 1 if (bpq090b==1 &bpq090b!=7&bpq090b!=9&bpq090b!=.) ///
& (survey_year == 2007 | survey_year == 2009 )
replace advice = 0 if (bpq090b==2 &bpq090b!=7&bpq090b!=9&bpq090b!=.) ///
& (survey_year == 2007 | survey_year == 2009 )
*2011, 2013. 2015
replace advice  = 1 if (mcq365a==1 &mcq365a!=7&mcq365a!=9&mcq365a!=.) ///
& (survey_year == 2011 | survey_year == 2013 |survey_year == 2015)
replace advice = 0 if (mcq365a==2 &mcq365a!=7&mcq365a!=9&mcq365a!=.) ///
& (survey_year == 2011 | survey_year == 2013 |survey_year == 2015)
bysort survey_year : tab advice
label variable advice "Advice"
**********************************************************************
**# HEALTH INSURANCE

// health insurance
gen hi = .
replace hi = 1 if (hiq011==1&hiq011!=7&hiq011!=9&hiq011!=.)
replace hi = 0 if (hiq011==2&hiq011!=7&hiq011!=9&hiq011!=.)
label variable hi "Health Insurance"
// routine care
gen rc = . 
replace rc = 1 if (huq030==1|huq030==3)&huq030!=7&huq030!=9&huq030!=.
replace rc = 0 if (huq030==2&huq030!=7&huq030!=9&huq030!=.)
label variable rc "Routine Care"

save "data_2007_2016.dta", replace

**# Save data in the analysis folder
global folder_analysis "FILEPATH_DATA" // FILEPATH_DATA is the folder where you will do the analysis
save "$folder_analysis/data_2007_2016.dta", replace

